.. gros documentation master file, created by
   sphinx-quickstart on Wed Aug  9 13:16:12 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to gros's documentation!
================================

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   src.gros_client.common
   src.gros_client.robot

